.. role:: bash(code)
   :language: bash

.. role:: python(code)
   :language: python


.. image:: https://user-images.githubusercontent.com/1635907/34374872-bc004152-eb26-11e7-9e72-9f0234ff5658.png
   :alt: [protoNN logo]
   :align: left

A framework for code-agnostic, interactive prototyping of DNNs.

.. image:: https://api.travis-ci.org/protoNN-ai/protoNN.svg?branch=master
    :target: https://travis-ci.org/protoNN-ao/protoNN
    :alt: build status from Travis CI

.. image:: https://coveralls.io/repos/github/undertherain/protoNN/badge.svg?branch=master
    :target: https://coveralls.io/github/undertherain/protoNN?branch=master

.. image:: https://badge.fury.io/py/protonn.svg
    :target: https://badge.fury.io/py/protonn
    :alt: pypi version


Features
--------
* Transparent and elastic scheduling of DNN training jobs on modern HPC systems.
* Monitoring and visualizing model parameters and computational performance statistics.
* Perform semi-automatic hyperparameter tuning/optimization and architecture search using evolutionary algorithms.
* A user-defined interactive interface to drive the framework/ design process, not bound to any particular framework.
* Scaling the functionality and performance of the model as the resources increase. 


How do I get set up?
--------------------

* ``pip3 install protonn`` for latest stable release
* ``pip3 install git+https://github.com/protoNN-ai/protoNN.git`` for recent development version
* Python 3.6 or later is required


Contributors
------------

Aleksandr Drozd

Mohamed Wahib

Mateusz Bysiek

Maxim Shpakovich

For licensing information, please see `<LICENSE>`_
